<?php
/*
Plugin Name: Chmurka tagów by Kubu - widget
Description: Dodaje widget "Chmurka tagów by Kubu" wyświetlający wybraną ilość tagów
Author: Kubu
Version: 1.0
*/

/**
* Adds Tag cloud widget
*/
class Tagcloud_Widget extends WP_Widget {

  /**
  * Register widget with WordPress
  */
  function __construct() {
    parent::__construct(
      'tagcloud_widget', // Base ID
      esc_html__( 'Chmurka tagów by Kubu', 'textdomain' ), // Name
      array( 'description' => esc_html__( 'Wyświetla wybraną ilość tagów', 'textdomain' ), ) // Args
    );
  }

  /**
  * Widget Fields
  */
  private $widget_fields = array(
    array(
      'label' => 'Ilość',
      'id' => 'w_count',
      'default' => '10',
      'type' => 'number',
    ),
    array(
      'label' => 'Sortuj po ("name" lub "count")',
      'id' => 'w_order_by',
      'default' => 'count',
      'type' => 'text',
    ),
    array(
      'label' => 'Kolejność sortowania ("ASC" - rosnąco, "DSC" - malejąco or "RAND" - losowo)',
      'id' => 'w_order',
      'default' => 'DSC',
      'type' => 'text',
    ),
    array(
      'label' => 'Najmniejszy rozmiar tagu',
      'id' => 'w_smalest',
      'default' => '8',
      'type' => 'number',
    ),
    array(
      'label' => 'Największy rozmiar tagu',
      'id' => 'w_largest',
      'default' => '22',
      'type' => 'number',
    ),
  );

  /**
  * Front-end display of widget
  */
  public function widget( $args, $instance ) {
    echo $args['before_widget'];

    // Output widget title
    if ( ! empty( $instance['title'] ) ) {
      echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
    }

    // Output generated fields
    wp_tag_cloud( array(
      'smallest'                  => $instance['w_smalest'], 
      'largest'                   => $instance['w_largest'],
      'unit'                      => 'px', 
      'number'                    => $instance['w_count'],  
      'orderby'                   => $instance['w_order_by'], 
      'order'                     => $instance['w_order'],
    ) );
    echo $args['after_widget'];
  }

  /**
  * Back-end widget fields
  */
  public function field_generator( $instance ) {
    $output = '';
    foreach ( $this->widget_fields as $widget_field ) {
      $widget_value = ! empty( $instance[$widget_field['id']] ) ? $instance[$widget_field['id']] : esc_html__( $widget_field['default'], 'textdomain' );
      switch ( $widget_field['type'] ) {
        default:
          $output .= '<p>';
          $output .= '<label for="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'">'.esc_attr( $widget_field['label'], 'textdomain' ).':</label> ';
          $output .= '<input class="widefat" id="'.esc_attr( $this->get_field_id( $widget_field['id'] ) ).'" name="'.esc_attr( $this->get_field_name( $widget_field['id'] ) ).'" type="'.$widget_field['type'].'" value="'.esc_attr( $widget_value ).'">';
          $output .= '</p>';
      }
    }
    echo $output;
  }

  public function form( $instance ) {
    $title = ! empty( $instance['title'] ) ? $instance['title'] : esc_html__( '', 'textdomain' );
    ?>
    <p>
    <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_attr_e( 'Title:', 'textdomain' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
    </p>
    <?php
    $this->field_generator( $instance );
  }

  /**
  * Sanitize widget form values as they are saved
  */
  public function update( $new_instance, $old_instance ) {
    $instance = array();
    $instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
    foreach ( $this->widget_fields as $widget_field ) {
      switch ( $widget_field['type'] ) {
        case 'checkbox':
          $instance[$widget_field['id']] = $_POST[$this->get_field_id( $widget_field['id'] )];
          break;
        default:
          $instance[$widget_field['id']] = ( ! empty( $new_instance[$widget_field['id']] ) ) ? strip_tags( $new_instance[$widget_field['id']] ) : '';
      }
    }
    return $instance;
  }
} // class Tagcloud_Widget

// register Tag cloud widget
function register_tagcloud_widget() {
  register_widget( 'Tagcloud_Widget' );
}
add_action( 'widgets_init', 'register_tagcloud_widget' );